Acknowledgements
-----------------

`alignparse <https://jbloomlab.github.io/alignparse/>`_ is written by `the Bloom lab <https://research.fhcrc.org/bloom/en.html>`_.

For the full list of contributors to `alignparse <https://jbloomlab.github.io/alignparse/>`_, `see here <https://github.com/jbloomlab/alignparse/graphs/contributors>`_.

If you use `alignparse <https://jbloomlab.github.io/alignparse/>`_ in your research, please cite the following reference:

Crawford KHD and Bloom JD. `"alignparse: A Python package for parsing complex features from high-throughput long-read sequencing." <https://doi.org/10.21105/joss.01915>`_. *Journal of Open Source Software*, 4:44, 1915 (2019).

If you use the :mod:`alignparse.minimap2` module to run `minimap2 <https://github.com/lh3/minimap2>`_, please also cite the `reference for minimap2 <https://academic.oup.com/bioinformatics/article/34/18/3094/4994778>`_.